async fn diagnostics_user_graph(
__arg0: State<DiagnosticsServices>,
__arg1: Path<(String, String)>,
) -> ResponseExpand description
node-graph projection rooted at one user in one room
async fn diagnostics_user_graph(
__arg0: State<DiagnosticsServices>,
__arg1: Path<(String, String)>,
) -> Responsenode-graph projection rooted at one user in one room